@@ -6,7 +6,6 @@ from fairies.read import (
 )
 
 from fairies.write import (
-    write_json,
     write_txt,
     write_npy
 )
@@ -64,6 +63,7 @@ from navinfo_tool.utils import (
     rm_bracketed,    # 去除文本中的括号，包括括号中的内容
     rm_symbol,    # 去除文本中的所有符号
     read_csv,    # 读取csv文件
+    write_json,    # 将json数据写到json文件中，解决了一些数据类型报错问题
     write2csv    # 将数组的内容写到csv中
 
 )
\ No newline at end of file
